@@ -5,84 +5,84 @@ and handles exceptions, chunked uploads or downloads, etc.
 
 from __future__ import annotations
 
+import functools
+
 # system imports
 import os
 import re
 import time
-import functools
-from contextlib import contextmanager, closing
+from contextlib import closing, contextmanager
 from datetime import datetime, timezone
 from typing import (
+    TYPE_CHECKING,
+    Any,
+    BinaryIO,
     Callable,
     Iterator,
     Sequence,
     TypeVar,
-    Any,
-    BinaryIO,
-    overload,
     cast,
-    TYPE_CHECKING,
+    overload,
 )
-from typing_extensions import ParamSpec, Concatenate
 
 # external imports
 import requests
-from dropbox import files, sharing, users, common
-from dropbox import Dropbox, create_session, exceptions
+from dropbox import Dropbox, common, create_session, exceptions, files, sharing, users
+from dropbox.dropbox_client import (
+    USER_AUTH,
+    BadInputException,
+    RouteErrorResult,
+    RouteResult,
+)
 from dropbox.oauth import DropboxOAuth2FlowNoRedirect
 from dropbox.session import API_HOST
-from dropbox.dropbox_client import (
-    BadInputException,
-    RouteResult,
-    RouteErrorResult,
-    USER_AUTH,
-)
+from typing_extensions import Concatenate, ParamSpec
 
 # local imports
 from . import __version__
-from .keyring import CredentialStorage
-from .logging import scoped_logger
+from .config import MaestralState
+from .constants import DROPBOX_APP_KEY
 from .core import (
-    AccountType,
-    Team,
     Account,
-    RootInfo,
-    UserRootInfo,
-    TeamRootInfo,
-    FullAccount,
-    SpaceUsage,
-    PersonalSpaceUsage,
-    WriteMode,
-    Metadata,
+    AccountType,
     DeletedMetadata,
     FileMetadata,
     FolderMetadata,
-    ListFolderResult,
+    FullAccount,
     LinkAccessLevel,
     LinkAudience,
     LinkPermissions,
-    SharedLinkMetadata,
+    ListFolderResult,
     ListSharedLinkResult,
-)
-from .exceptions import (
-    MaestralApiError,
-    SyncError,
-    PathError,
-    NotFoundError,
-    NotLinkedError,
-    DataCorruptionError,
-    DataChangedError,
+    Metadata,
+    PersonalSpaceUsage,
+    RootInfo,
+    SharedLinkMetadata,
+    SpaceUsage,
+    Team,
+    TeamRootInfo,
+    UserRootInfo,
+    WriteMode,
 )
 from .errorhandling import (
+    CONNECTION_ERRORS,
     convert_api_errors,
     dropbox_to_maestral_error,
-    CONNECTION_ERRORS,
 )
-from .config import MaestralState
-from .constants import DROPBOX_APP_KEY
-from .utils import natural_size, chunks, clamp
-from .utils.path import opener_no_symlink, delete
+from .exceptions import (
+    DataChangedError,
+    DataCorruptionError,
+    MaestralApiError,
+    NotFoundError,
+    NotLinkedError,
+    PathError,
+    SyncError,
+)
+from .keyring import CredentialStorage
+from .logging import scoped_logger
+from .utils import chunks, clamp, natural_size
 from .utils.hashing import DropboxContentHasher, StreamHasher
+from .utils.path import delete, opener_no_symlink
 
 if TYPE_CHECKING:
     from .models import SyncEvent
@@ -283,7 +283,7 @@ class DropboxClient:
                 if wait_time > self.DATA_TRANSFER_MIN_SLEEP_TIME:
                     time.sleep(wait_time)
 
-    def _throttled_upload_iter(self, data: bytes) -> Iterator[bytes] | bytes:
+    def _throttled_upload_iter(self, data: bytes) -> Iterator[bytes]:
         pos = 0
         while pos < len(data):
             tick = time.monotonic()
@@ -320,7 +320,7 @@ class DropboxClient:
         """
 
         def decorator(
-            func: Callable[Concatenate[DropboxClient, P], T]
+            func: Callable[Concatenate[DropboxClient, P], T],
         ) -> Callable[Concatenate[DropboxClient, P], T]:
             @functools.wraps(func)
             def wrapper(__self: DropboxClient, *args: P.args, **kwargs: P.kwargs) -> T:
@@ -919,7 +919,9 @@ class DropboxClient:
                 md = self.dbx.files_upload(
                     self._throttled_upload_iter(data),
                     dbx_path,
-                    client_modified=datetime.utcfromtimestamp(stat.st_mtime),
+                    client_modified=datetime.fromtimestamp(
+                        stat.st_mtime, tz=timezone.utc
+                    ),
                     content_hash=get_hash(data),
                     mode=mode,
                     autorename=autorename,
@@ -1035,7 +1037,7 @@ class DropboxClient:
         # Finish upload session and return metadata.
         commit = files.CommitInfo(
             path=dbx_path,
-            client_modified=datetime.utcfromtimestamp(stat.st_mtime),
+            client_modified=datetime.fromtimestamp(stat.st_mtime, tz=timezone.utc),
             autorename=autorename,
             mode=mode,
         )
