@@ -11,18 +11,17 @@ config module of the Spyder IDE.
 from __future__ import annotations
 
 import ast
+import configparser as cp
+import copy
+import logging
 import os
 import os.path as osp
 import shutil
-import copy
-import logging
-import configparser as cp
 from threading import RLock
-from typing import Iterator, Any, Dict, TypeVar, MutableSet
+from typing import Any, Dict, Iterator, MutableSet, TypeVar, Iterable
 
 from packaging.version import Version
 
-
 logger = logging.getLogger(__name__)
 
 _DefaultsType = Dict[str, Dict[str, Any]]
@@ -502,14 +501,14 @@ class PersistentMutableSet(MutableSet[_T]):
             state_list.discard(entry)
             self._conf.set(self.section, self.option, list(state_list))
 
-    def update(self, *others: _T) -> None:
+    def update(self, *others: Iterable[_T]) -> None:
         with self._lock:
             state_list = self._conf.get(self.section, self.option)
             state_list = set(state_list)
             state_list.update(*others)
             self._conf.set(self.section, self.option, list(state_list))
 
-    def difference_update(self, *others: _T) -> None:
+    def difference_update(self, *others: Iterable[_T]) -> None:
         with self._lock:
             state_list = self._conf.get(self.section, self.option)
             state_list = set(state_list)
