@@ -4,10 +4,10 @@ from datetime import datetime, timezone
 
 from dropbox import files
 
-from maestral.core import FileMetadata
 from maestral.client import DropboxClient
-from maestral.exceptions import NotFoundError, FileConflictError
+from maestral.core import FileMetadata
 from maestral.errorhandling import convert_api_errors
+from maestral.exceptions import FileConflictError, NotFoundError
 
 
 class DropboxTestLock:
@@ -53,7 +53,9 @@ class DropboxTestLock:
         t0 = time.time()
 
         # we store the expiry time in the client_modified time stamp
-        expiry_time = datetime.utcfromtimestamp(time.time() + self.expires_after)
+        expiry_time = datetime.fromtimestamp(
+            time.time() + self.expires_after, tz=timezone.utc
+        )
 
         while True:
             try:
