@@ -2,15 +2,14 @@ import logging
 
 from click.testing import CliRunner
 
-from maestral.main import Maestral
-from maestral.cli import main
 from maestral.autostart import AutoStart
-from maestral.notify import level_number_to_name, level_name_to_number
-from maestral.daemon import MaestralProxy, start_maestral_daemon_process, Start
+from maestral.cli import main
+from maestral.daemon import MaestralProxy, Start, start_maestral_daemon_process
 from maestral.logging import scoped_logger
+from maestral.main import Maestral
+from maestral.notify import level_name_to_number, level_number_to_name
 from maestral.utils.appdirs import get_log_path
 
-
 TEST_TIMEOUT = 60
 
 
@@ -21,7 +20,8 @@ def test_help() -> None:
     result_no_arg = runner.invoke(main)
     result_help_arg = runner.invoke(main, ["--help"])
 
-    assert result_no_arg.exit_code == 0, result_no_arg.output
+    assert result_no_arg.exit_code == 2, result_no_arg.output
+    assert result_help_arg.exit_code == 0, result_no_arg.output
     assert result_no_arg.output.startswith("Usage: main [OPTIONS] COMMAND [ARGS]")
 
     assert result_no_arg.output == result_help_arg.output
